@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2010-2016 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2010-2024 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -20,28 +20,6 @@
 
 //-----------------------------------------------------------------------------
 
-namespace
-{
-
-QPixmap coloredShadow(const QColor& color)
-{
-	QPixmap source(":/shadow.png");
-	QImage shadow(source.size(), QImage::Format_ARGB32_Premultiplied);
-	QPainter painter(&shadow);
-	painter.setCompositionMode(QPainter::CompositionMode_Source);
-	painter.drawPixmap(0, 0, source);
-	painter.setCompositionMode(QPainter::CompositionMode_SourceIn);
-	painter.fillRect(shadow.rect(), color);
-	painter.end();
-	return QPixmap::fromImage(shadow, Qt::AvoidDither | Qt::AutoColor | Qt::NoOpaqueDetection);
-}
-
-}
-
-bool AppearanceDialog::m_bevels_enabled = true;
-
-//-----------------------------------------------------------------------------
-
 AppearanceDialog::AppearanceDialog(QWidget* parent)
 	: QDialog(parent, Qt::WindowTitleHint | Qt::WindowSystemMenuHint)
 {
@@ -101,16 +79,12 @@ AppearanceDialog::AppearanceDialog(QWidget* parent)
 	layout->addWidget(buttons, 4, 0, 1, 2);
 
 	// Load settings
-	QSettings settings;
+	const QSettings settings;
 	m_background->setColor(settings.value("Colors/Background", QColor(0x9d, 0x89, 0x75)).value<QColor>());
 	m_shadow->setColor(settings.value("Colors/Shadow", QColor(Qt::black)).value<QColor>());
 	m_highlight->setColor(settings.value("Colors/Highlight", QColor(Qt::white)).value<QColor>());
 	m_has_bevels->setChecked(settings.value("Appearance/Bevels", true).toBool());
 	m_has_shadows->setChecked(settings.value("Appearance/Shadows", true).toBool());
-	if (!m_bevels_enabled) {
-		m_has_bevels->setChecked(false);
-		m_has_bevels->setEnabled(false);
-	}
 	updatePreview();
 }
 
@@ -141,9 +115,16 @@ QPalette AppearanceDialog::colors() const
 
 //-----------------------------------------------------------------------------
 
-void AppearanceDialog::setBevelsEnabled(bool enabled)
+QPixmap AppearanceDialog::shadow(qreal pixelratio)
 {
-	m_bevels_enabled = enabled;
+	return coloredShadow(QSettings().value("Colors/Shadow", QColor(Qt::black)).value<QColor>(), pixelratio);
+}
+
+//-----------------------------------------------------------------------------
+
+QPixmap AppearanceDialog::shadowSelected(qreal pixelratio)
+{
+	return coloredShadow(QSettings().value("Colors/Highlight", QColor(Qt::white)).value<QColor>(), pixelratio);
 }
 
 //-----------------------------------------------------------------------------
@@ -175,46 +156,50 @@ void AppearanceDialog::restoreDefaults()
 
 void AppearanceDialog::updatePreview()
 {
-	QPixmap bumpmap;
-	if (m_has_bevels->isChecked()) {
-		bumpmap.load(":/bumpmap.png");
-	} else {
-		bumpmap = QPixmap(512, 512);
-		bumpmap.fill(QColor(128, 128, 128));
-	}
+	const qreal pixelratio = devicePixelRatioF();
 
-	QPixmap pixmap(352, 256);
+	QPixmap bumpmap(512, 512);
+	bumpmap.fill(QColor(128, 128, 128));
+	if (m_has_bevels->isChecked()) {
+		QPainter painter(&bumpmap);
+		painter.drawPixmap(0, 0, QPixmap(":/bumpmap.png"));
+	}
+	bumpmap = bumpmap.scaled(bumpmap.size() * pixelratio, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+	bumpmap.setDevicePixelRatio(pixelratio);
+
+	QPixmap pixmap(352 * pixelratio, 256 * pixelratio);
+	pixmap.setDevicePixelRatio(pixelratio);
 	pixmap.fill(m_background->color());
 	{
 		QPainter painter(&pixmap);
 
 		// Draw example piece
 		if (m_has_shadows->isChecked()) {
-			QPixmap shadow = coloredShadow(m_shadow->color());
+			QPixmap shadow = coloredShadow(m_shadow->color(), pixelratio);
 			for (int i = 0; i < 3; ++i) {
 				painter.drawPixmap(0, i * 64, shadow);
 			}
 			painter.drawPixmap(64, 64, shadow);
 		}
-		painter.drawPixmap(32, 32, bumpmap, 288, 416, 64, 64);
-		painter.drawPixmap(32, 96, bumpmap, 32, 32, 64, 64);
-		painter.drawPixmap(96, 96, bumpmap, 160, 416, 64, 64);
-		painter.drawPixmap(32, 160, bumpmap, 32, 416, 64, 64);
+		painter.drawPixmap(32, 32, bumpmap, 288 * pixelratio, 416 * pixelratio, 64 * pixelratio, 64 * pixelratio);
+		painter.drawPixmap(32, 96, bumpmap, 32 * pixelratio, 32 * pixelratio, 64 * pixelratio, 64 * pixelratio);
+		painter.drawPixmap(96, 96, bumpmap, 160 * pixelratio, 416 * pixelratio, 64 * pixelratio, 64 * pixelratio);
+		painter.drawPixmap(32, 160, bumpmap, 32 * pixelratio, 416 * pixelratio, 64 * pixelratio, 64 * pixelratio);
 
 		// Draw example highlighted piece
 		painter.translate(160, 0);
 
 		if (m_has_shadows->isChecked()) {
-			QPixmap highlight = coloredShadow(m_highlight->color());
+			QPixmap highlight = coloredShadow(m_highlight->color(), pixelratio);
 			for (int i = 0; i < 3; ++i) {
 				painter.drawPixmap(0, i * 64, highlight);
 			}
 			painter.drawPixmap(64, 64, highlight);
 		}
-		painter.drawPixmap(32, 32, bumpmap, 288, 416, 64, 64);
-		painter.drawPixmap(32, 96, bumpmap, 32, 32, 64, 64);
-		painter.drawPixmap(96, 96, bumpmap, 160, 416, 64, 64);
-		painter.drawPixmap(32, 160, bumpmap, 32, 416, 64, 64);
+		painter.drawPixmap(32, 32, bumpmap, 288 * pixelratio, 416 * pixelratio, 64 * pixelratio, 64 * pixelratio);
+		painter.drawPixmap(32, 96, bumpmap, 32 * pixelratio, 32 * pixelratio, 64 * pixelratio, 64 * pixelratio);
+		painter.drawPixmap(96, 96, bumpmap, 160 * pixelratio, 416 * pixelratio, 64 * pixelratio, 64 * pixelratio);
+		painter.drawPixmap(32, 160, bumpmap, 32 * pixelratio, 416 * pixelratio, 64 * pixelratio, 64 * pixelratio);
 	}
 
 	QPalette palette = m_preview->palette();
@@ -225,3 +210,23 @@ void AppearanceDialog::updatePreview()
 }
 
 //-----------------------------------------------------------------------------
+
+QPixmap AppearanceDialog::coloredShadow(const QColor& color, qreal pixelratio)
+{
+	const QPixmap source(":/shadow.png");
+	QImage shadow(source.size(), QImage::Format_ARGB32_Premultiplied);
+	QPainter painter(&shadow);
+	painter.setCompositionMode(QPainter::CompositionMode_Source);
+	painter.drawPixmap(0, 0, source);
+	painter.setCompositionMode(QPainter::CompositionMode_SourceIn);
+	painter.fillRect(shadow.rect(), color);
+	painter.end();
+
+	QPixmap result = QPixmap::fromImage(shadow.scaled(shadow.size() * pixelratio, Qt::IgnoreAspectRatio, Qt::SmoothTransformation),
+			Qt::AvoidDither | Qt::AutoColor | Qt::NoOpaqueDetection);
+	result.setDevicePixelRatio(pixelratio);
+
+	return result;
+}
+
+//-----------------------------------------------------------------------------
