@@ -1,5 +1,5 @@
 /*
-	SPDX-FileCopyrightText: 2008-2023 Graeme Gott <graeme@gottcode.org>
+	SPDX-FileCopyrightText: 2008-2024 Graeme Gott <graeme@gottcode.org>
 
 	SPDX-License-Identifier: GPL-3.0-or-later
 */
@@ -18,7 +18,6 @@
 #include <QCloseEvent>
 #include <QDialog>
 #include <QDialogButtonBox>
-#include <QFileInfo>
 #include <QGridLayout>
 #include <QLabel>
 #include <QMenu>
@@ -38,14 +37,15 @@ Window::Window(const QStringList& files)
 	resize(640, 480);
 
 	// Add statusbar
+	m_completed = new QProgressBar(this);
+	m_completed->setFormat(tr("%p% complete"));
+	m_completed->setRange(0, 100);
+	m_completed->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Maximum);
+	statusBar()->addPermanentWidget(m_completed);
+
 	m_slider = new ZoomSlider(this);
 	statusBar()->addPermanentWidget(m_slider);
 
-	m_completed = new QProgressBar(this);
-	m_completed->setRange(0, 100);
-	m_completed->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
-	statusBar()->addPermanentWidget(m_completed);
-
 	statusBar()->setMinimumHeight(statusBar()->sizeHint().height());
 	m_slider->hide();
 	m_completed->hide();
@@ -57,7 +57,12 @@ Window::Window(const QStringList& files)
 	connect(m_board, &Board::clearMessage, statusBar(), &QStatusBar::clearMessage);
 	connect(m_board, &Board::showMessage, statusBar(), &QStatusBar::showMessage);
 	connect(m_board, &Board::zoomChanged, m_slider, &ZoomSlider::setValue);
-	connect(m_slider, &ZoomSlider::valueChanged, m_board, &Board::zoom);
+	connect(m_slider, &ZoomSlider::valueChanged, this, [this](int value) {
+		m_board->zoom(value, true);
+	});
+	connect(m_slider, &ZoomSlider::zoomFit, m_board, &Board::zoomFit);
+	connect(m_slider, &ZoomSlider::zoomIn, m_board, &Board::zoomIn);
+	connect(m_slider, &ZoomSlider::zoomOut, m_board, &Board::zoomOut);
 	setCentralWidget(m_board);
 
 	// Add menus
@@ -65,7 +70,7 @@ Window::Window(const QStringList& files)
 
 	menu = menuBar()->addMenu(tr("&Game"));
 	QAction* choose_action = menu->addAction(tr("&Choose..."), this, [this]() { chooseGame(QStringList()); });
-	choose_action->setShortcuts(QList<QKeySequence>() << QKeySequence::New << QKeySequence::Open);
+	choose_action->setShortcuts({ QKeySequence::New, QKeySequence::Open});
 	menu->addSeparator();
 	QAction* retrieve_pieces_action = menu->addAction(tr("&Retrieve Pieces"), m_board, &Board::retrievePieces);
 	retrieve_pieces_action->setShortcut(tr("Ctrl+R"));
@@ -80,11 +85,11 @@ Window::Window(const QStringList& files)
 	QAction* zoom_in_action = menu->addAction(tr("Zoom &In"), m_board, &Board::zoomIn);
 	zoom_in_action->setShortcut(tr("+"));
 	zoom_in_action->setEnabled(false);
-	connect(m_board, &Board::zoomInAvailable, zoom_in_action, &QAction::setEnabled);
+	connect(m_slider, &ZoomSlider::zoomInAvailable, zoom_in_action, &QAction::setEnabled);
 	QAction* zoom_out_action = menu->addAction(tr("Zoom &Out"), m_board, &Board::zoomOut);
 	zoom_out_action->setShortcut(tr("-"));
 	zoom_out_action->setEnabled(false);
-	connect(m_board, &Board::zoomOutAvailable, zoom_out_action, &QAction::setEnabled);
+	connect(m_slider, &ZoomSlider::zoomOutAvailable, zoom_out_action, &QAction::setEnabled);
 	m_zoom_fit_action = menu->addAction(tr("Best &Fit"), m_board, &Board::zoomFit);
 	m_zoom_fit_action->setEnabled(false);
 	menu->addSeparator();
@@ -145,16 +150,6 @@ void Window::addImages(const QStringList& files)
 
 //-----------------------------------------------------------------------------
 
-void Window::changeEvent(QEvent* event)
-{
-	if (event->type() == QEvent::WindowStateChange) {
-		m_board->update();
-	}
-	return QMainWindow::changeEvent(event);
-}
-
-//-----------------------------------------------------------------------------
-
 void Window::closeEvent(QCloseEvent* event)
 {
 	QSettings().setValue("Geometry", saveGeometry());
@@ -175,7 +170,7 @@ void Window::dragEnterEvent(QDragEnterEvent* event)
 
 void Window::dropEvent(QDropEvent* event)
 {
-	QStringList files = AddImage::dropEvent(event);
+	const QStringList files = AddImage::dropEvent(event);
 	if (!files.isEmpty()) {
 		chooseGame(files);
 	}
