@@ -7,6 +7,10 @@
         <source>Open Image</source>
         <translation>Άνοιγμα Εικόνας</translation>
     </message>
+    <message>
+        <source>Images</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AppearanceDialog</name>
@@ -120,6 +124,10 @@
         <source>New Game</source>
         <translation>Καινούργιο παιχνίδι</translation>
     </message>
+    <message>
+        <source>Play Game</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImagePropertiesDialog</name>
@@ -135,6 +143,10 @@
         <source>Tags:</source>
         <translation>Κατηγορία:</translation>
     </message>
+    <message>
+        <source>New tag name</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LocaleDialog</name>
@@ -181,22 +193,28 @@
         <source>Cancel</source>
         <translation>Ακύρωση</translation>
     </message>
-    <message>
-        <source>Remove selected image?</source>
-        <translation>Αφαίρεση της επιλεγμένης εικόνας;</translation>
-    </message>
-    <message>
-        <source>Remove selected image?
-
-There are saved games using this image that will also be removed.</source>
-        <translation>Αφαίρεση της επιλεγμένης εικόνας;
-
-Εκεί αποθηκεύονται τα παιχνίδια που χρησιμοποιούν αυτή την εικόνα που θα πρέπει επίσης να αφαιρεθεί.</translation>
-    </message>
     <message>
         <source>Untitled</source>
         <translation>Χωρίς τίτλο</translation>
     </message>
+    <message numerus="yes">
+        <source>Remove %n selected image(s)?</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved games using these image(s) will be deleted.</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>OpenGameTab</name>
@@ -266,6 +284,10 @@ There are saved games using this image that will also be removed.</source>
         <source>A tag with that name already exists.</source>
         <translation>Μια κατηγορία με αυτό το όνομα υπάρχει ήδη.</translation>
     </message>
+    <message>
+        <source>Manage Tags...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Window</name>
@@ -437,28 +459,20 @@ There are saved games using this image that will also be removed.</source>
         <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
         <translation>Κυκλοφορία υπο την άδεια &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
     </message>
+    <message>
+        <source>%p% complete</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ZoomSlider</name>
     <message>
-        <source>??%</source>
-        <translation>;;%</translation>
-    </message>
-    <message>
-        <source>%1%</source>
-        <translation>%1%</translation>
+        <source>Zoom: %1%</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>main</name>
-    <message>
-        <source>Select OpenGL version.</source>
-        <translation>Επιλογή έκδοσης OpenGL.</translation>
-    </message>
-    <message>
-        <source>version</source>
-        <translation>έκδοση</translation>
-    </message>
     <message>
         <source>Images to add to the choose game dialog.</source>
         <translation type="unfinished"></translation>
